chatter package — django-chats 0.1.1 documentation

# chatter package

## Subpackages

- chatter.api package
  - Submodules
  - chatter.api.serializers module
  - chatter.api.urls module
  - chatter.api.views module
  - Module contents
- chatter.migrations package
  - Submodules
  - chatter.migrations.0001_initial module
  - chatter.migrations.0002_auto_20200922_1209 module
  - chatter.migrations.0003_auto_20200922_1221 module
  - chatter.migrations.0004_auto_20200925_1757 module
  - chatter.migrations.0005_auto_20200925_1856 module
  - Module contents
- chatter.test_utils package
  - Subpackages
    - chatter.test_utils.test_app package
      - Subpackages
        - chatter.test_utils.test_app.migrations package
          - Module contents
      - Submodules
      - chatter.test_utils.test_app.admin module
      - chatter.test_utils.test_app.apps module
      - chatter.test_utils.test_app.models module
      - Module contents
  - Module contents

## Submodules

## chatter.admin module

## chatter.apps module

class `chatter.apps.` `chatter`(app_name, app_module)

  Bases: `django.apps.config.AppConfig`

  `name` = 'chatter'

## chatter.consumers module

## chatter.forms module

## chatter.messages module

class `chatter.messages.` `BaseMessage`(data, *args, **kwargs)

  Bases: `object`

  minimal class which may be used for writing custom Message implementations

class `chatter.messages.` `Message`(data, *args, **kwargs)

  Bases: `chatter.messages.BaseMessage`

## chatter.models module

## chatter.routings module

## chatter.urls module

## chatter.views module

## Module contents